# Write a .pdf file ------------------------------------------------------------
pdf(file="disparity_rate_fig.pdf",
   width=14, height=10, pointsize=18)

## set up the layout and pars --------------------------------------------------
# m <- rbind(c(1,1,1,1,1,1,2,3), 
#            c(4,4,4,4,4,4,5,6),
#            c(7,7,7,7,7,7,8,9),
#            c(10,10,10,10,10,10,11,12))
#layout(m)
par(mfrow=c(4,1),
    mar=c(0,0,0,0),
    oma=c(5,1,0.5,0.5),
    plt=c(0.15, 0.9, 0.1, 0.9))
par(xpd=NA)

## Set up some common things that all panels will use --------------------------
plt.cex = 2.5
plt.lwd = 1
text.cex = 1
left.axis = -2
right.axis = 42.75
xrange <- 3:37
plot.xs <- c(3,37)
dispcol <- "red"
ratecol <- "blue"
wristcol <- "gray30"
panelx <- -4
panel.cex <- 1.75
means.pch <- 18
means.cex <- 2.5
wristpos <- 23

## First row of plots: camber --------------------------------------------------
# First plot: Camber disparity and sig^2 traces
plot.ys <- c(min(camb.Sig2[1,]), max(camb.Sig2[1,]))

plot(plot.xs, plot.ys, type="n", col="white", bg="blue", cex=2, axes=FALSE, ann=FALSE)

segments(wristpos, plot.ys[1], wristpos, plot.ys[2], lty=2, col=wristcol, lend=2)

#points(c(5:40), camb.Sig2[1,], col="blue", type="l", lty=3)
points(xrange, camb.Sig2[1,], col=ratecol, type="l", lwd=plt.lwd, lend=1)

axis(4, lend=1, ljoin=1)

par(new=TRUE)

plot(xrange, camb.disparity.l$disparity[[1]]$elements, type="l", col=dispcol, lwd=plt.lwd, axes=FALSE, ann=FALSE, lend=1)
text(left.axis, mean(range(camb.disparity.l$disparity[[1]]$elements)), "Disparity", srt=90, cex=text.cex)
text(right.axis, mean(range(camb.disparity.l$disparity[[1]]$elements)), expression(paste(sigma)^"2"), srt=90, cex=text.cex)
text(panelx, max(camb.disparity.l$disparity[[1]]$elements), "i.", cex=panel.cex)

axis(1, at=c(3, 23, 37), labels=FALSE, lend=1, ljoin=1)
axis(2, lend=1, ljoin=1)

par(new=TRUE)
plot(xrange, camb.disparity.l$disparity[[1]]$elements, type="n", axes=FALSE, ann=FALSE)
points(c(3:22), camb.rdd$fitted.values[1:20], type="l", lwd=2, lend=1)
points(c(23:37), camb.rdd$fitted.values[21:35], type="l", lwd=2, lend=1)


## Second row of plots: chord --------------------------------------------------
# First plot: Chord disparity and sig^2 traces
plot.ys <- c(min(chord.Sig2[1,]), max(chord.Sig2[1,]))
plot(plot.xs, plot.ys, type="n", col="white", bg="blue", cex=2, axes=FALSE, ann=FALSE)

segments(wristpos, plot.ys[1], wristpos, plot.ys[2], lty=2, col=wristcol, lend=2)

#points(c(5:40), chord.Sig2[1,], col="blue", type="l", lty=3)
points(xrange, chord.Sig2[1,], col=ratecol, type="l", lend=1)

axis(4, lend=1, ljoin=1)

par(new=TRUE)

plot(xrange, chord.disparity.l$disparity[[1]]$elements, type="l", col=dispcol, lwd=plt.lwd, axes=FALSE, ann=FALSE, lend=1)
text(left.axis, mean(range(chord.disparity.l$disparity[[1]]$elements)), "Disparity", srt=90, cex=text.cex)
text(right.axis, mean(range(chord.disparity.l$disparity[[1]]$elements)), expression(paste(sigma)^"2"), srt=90, cex=text.cex)
text(panelx, max(chord.disparity.l$disparity[[1]]$elements), "ii.", cex=panel.cex)

axis(1, at=c(3, 23, 37), labels=FALSE, lend=1, ljoin=1)
axis(2, lend=1, ljoin=1)

par(new=TRUE)
plot(xrange, chord.disparity.l$disparity[[1]]$elements, type="n", axes=FALSE, ann=FALSE)
points(c(3:22), chord.rdd$fitted.values[1:20], type="l", lwd=2, lend=1)
points(c(23:37), chord.rdd$fitted.values[21:35], type="l", lwd=2, lend=1)

## Third row of plots: Cross-sectional thickness -------------------------------
# First plot: Cross-sectional Thickness disparity and sig.^2 traces
plot.ys <- c(min(xst.Sig2[1,]), max(xst.Sig2[1,]))

plot(plot.xs, plot.ys, type="n", col="white", bg="blue", cex=2, axes=FALSE, ann=FALSE)

segments(wristpos, plot.ys[1], wristpos, plot.ys[2], lty=2, col=wristcol, lend=2)

#points(c(5:40), xst.Sig2[1,], col="blue", type="l", lty=3)
points(xrange, xst.Sig2[1,], col=ratecol, type="l", lend=1)

axis(4, lend=1, ljoin=1)

par(new=TRUE)

plot(xrange, xst.disparity.l$disparity[[1]]$elements, type="l", col=dispcol, lwd=plt.lwd, axes=FALSE,ann=FALSE, lend=1)
text(left.axis, mean(range(xst.disparity.l$disparity[[1]]$elements)), "Disparity", srt=90, cex=text.cex)
text(right.axis, mean(range(xst.disparity.l$disparity[[1]]$elements)), expression(paste(sigma)^"2"), srt=90, cex=text.cex)
text(panelx, max(xst.disparity.l$disparity[[1]]$elements), "iii.", cex=panel.cex)

axis(1, at=c(3, 23, 37), labels=FALSE, lend=1, ljoin=1)
axis(2, lend=1, ljoin=1)

par(new=TRUE)
plot(xrange, xst.disparity.l$disparity[[1]]$elements, type="n", axes=FALSE, ann=FALSE)
points(c(3:22), xst.rdd$fitted.values[1:20], type="l", lwd=2, lend=1)
points(c(23:37), xst.rdd$fitted.values[21:35], type="l", lwd=2, lend=1)

## Fourth row of plots: Cross sectional area -----------------------------------
# First plot: Cross-sectional Area disparity and sig.^2 traces
plot.ys <- c(min(xsa.Sig2[1,]), max(xsa.Sig2[1,]))

plot(plot.xs, plot.ys, type="n", col="white", bg="blue", cex=2, axes=FALSE, ann=FALSE)

segments(wristpos, plot.ys[1], wristpos, plot.ys[2], lty=2, col=wristcol, lend=2)

#points(c(5:40), xsa.Sig2[1,], col="blue", type="l", lty=3)
points(xrange, xsa.Sig2[1,], col=ratecol, type="l", lend=1)

axis(4, lend=1, ljoin=1)

par(new=TRUE)

plot(xrange, xsa.disparity.l$disparity[[1]]$elements, type="l", col=dispcol, lwd=plt.lwd, axes=FALSE, ann=FALSE, lend=1)
text(left.axis, mean(range(xsa.disparity.l$disparity[[1]]$elements)), "Disparity", srt=90, cex=text.cex)
text(right.axis, mean(range(xsa.disparity.l$disparity[[1]]$elements)), expression(paste(sigma)^"2"), srt=90, cex=text.cex)
text(panelx, max(xsa.disparity.l$disparity[[1]]$elements), "iv.", cex=panel.cex)
#text(mean(xrange), -0.2, "Position along Wing Span")
axis(1, at=c(3, 23, 37), labels=c("Tip", "Wrist", "Shoulder"), lend=1, ljoin=1)
axis(2, lend=1, ljoin=1)

par(new=TRUE)
plot(xrange, xsa.disparity.l$disparity[[1]]$elements, type="n", axes=FALSE, ann=FALSE)
points(c(3:22), xsa.rdd$fitted.values[1:20], type="l", lwd=2, lend=1)
points(c(23:37), xsa.rdd$fitted.values[21:35], type="l", lwd=2, lend=1)

## End -------------------------------------------------------------------------
dev.off()

## Unused code -----------------------------------------------------------------
# # Second plot
# plot(c(0.25,1.75), range(camb.disparity.l$disparity[[1]]$elements), type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(camb.disparity.l$disparity[[1]]$elements)[1], 1, range(camb.disparity.l$disparity[[1]]$elements)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# segments(0.5, mean(camb.disparity.l$disparity[[1]]$elements[1:length(hwidx)])+sd(camb.disparity.l$disparity[[1]]$elements[1:length(hwidx)]),
#          0.5, mean(camb.disparity.l$disparity[[1]]$elements[1:length(hwidx)])-sd(camb.disparity.l$disparity[[1]]$elements[1:length(hwidx)]),
#          lwd=1.5, col=dispcol)
# segments(1.5, mean(camb.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1])+sd(camb.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]),
#          1.5, mean(camb.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1])-sd(camb.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]),
#          lwd=1.5, col=dispcol)
# points(0.5, mean(camb.disparity.l$disparity[[1]]$elements[1:length(hwidx)]), col=dispcol, pch=means.pch, cex=means.cex)
# points(1.5, mean(camb.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]), col=dispcol, pch=means.pch, cex=means.cex)
# 
# text(1, max(camb.disparity.l$disparity[[1]]$elements), "**", cex=means.cex)
# 
# # Third plot
# plot(c(0.25,1.75), plot.ys, type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(plot.ys)[1], 1, range(plot.ys)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# segments(0.5, mean(as.numeric(camb.Sig2[1, 1:length(hwidx)]))+sd(as.numeric(camb.Sig2[1, 1:length(hwidx)])),
#          0.5, mean(as.numeric(camb.Sig2[1, 1:length(hwidx)]))-sd(as.numeric(camb.Sig2[1, 1:length(hwidx)])),
#          lwd=1.5, col=ratecol)
# segments(1.5, mean(as.numeric(camb.Sig2[1, 1+length(hwidx):length(slicerange)-1]))+sd(as.numeric(camb.Sig2[1, 1+length(hwidx):length(slicerange)-1])),
#          1.5, mean(as.numeric(camb.Sig2[1, 1+length(hwidx):length(slicerange)-1]))-sd(as.numeric(camb.Sig2[1, 1+length(hwidx):length(slicerange)-1])),
#          lwd=1.5, col=ratecol)
# points(0.5, mean(as.numeric(camb.Sig2[1, 1:length(hwidx)])), col=ratecol, pch=means.pch, cex=means.cex)
# points(1.5, mean(as.numeric(camb.Sig2[1, 1+length(hwidx):length(slicerange)-1])), col=ratecol, pch=means.pch, cex=means.cex)

# # Second plot: Disparity means
# plot(c(0.25,1.75), range(chord.disparity.l$disparity[[1]]$elements), type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(chord.disparity.l$disparity[[1]]$elements)[1], 1, range(chord.disparity.l$disparity[[1]]$elements)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# segments(0.5, mean(chord.disparity.l$disparity[[1]]$elements[1:length(hwidx)])+sd(chord.disparity.l$disparity[[1]]$elements[1:length(hwidx)]),
#          0.5, mean(chord.disparity.l$disparity[[1]]$elements[1:length(hwidx)])-sd(chord.disparity.l$disparity[[1]]$elements[1:length(hwidx)]),
#          lwd=1.5, col=dispcol)
# segments(1.5, mean(chord.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1])+sd(chord.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]),
#          1.5, mean(chord.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1])-sd(chord.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]),
#          lwd=1.5, col=dispcol)
# points(0.5, mean(chord.disparity.l$disparity[[1]]$elements[1:length(hwidx)]), col=dispcol, pch=means.pch, cex=means.cex)
# points(1.5, mean(chord.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]), col=dispcol, pch=means.pch, cex=means.cex)
# 
# text(1, max(chord.disparity.l$disparity[[1]]$elements), "*", cex=means.cex)
# 
# # Third plot: Sigma^2 means
# plot(c(0.25,1.75), plot.ys, type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(plot.ys)[1], 1, range(plot.ys)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# segments(0.5, mean(as.numeric(chord.Sig2[1, 1:length(hwidx)]))+sd(as.numeric(chord.Sig2[1, 1:length(hwidx)])),
#          0.5, mean(as.numeric(chord.Sig2[1, 1:length(hwidx)]))-sd(as.numeric(chord.Sig2[1, 1:length(hwidx)])),
#          lwd=1.5, col=ratecol)
# segments(1.5, mean(as.numeric(chord.Sig2[1, 1+length(hwidx):length(slicerange)-1]))+sd(as.numeric(chord.Sig2[1, 1+length(hwidx):length(slicerange)-1])),
#          1.5, mean(as.numeric(chord.Sig2[1, 1+length(hwidx):length(slicerange)-1]))-sd(as.numeric(chord.Sig2[1, 1+length(hwidx):length(slicerange)-1])),
#          lwd=1.5, col=ratecol)
# points(0.5, mean(as.numeric(chord.Sig2[1, 1:length(hwidx)])), col=ratecol, pch=means.pch, cex=means.cex)
# points(1.5, mean(as.numeric(chord.Sig2[1, 1+length(hwidx):length(slicerange)-1])), col=ratecol, pch=means.pch, cex=means.cex)
# 
# text(1, max(as.numeric(chord.Sig2[1,])), "*", cex=means.cex)

# # Second plot
# plot(c(0.25,1.75), range(xst.disparity.l$disparity[[1]]$elements), type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(xst.disparity.l$disparity[[1]]$elements)[1], 1, range(xst.disparity.l$disparity[[1]]$elements)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# points(0.5, mean(xst.disparity.l$disparity[[1]]$elements[1:length(hwidx)]), col=dispcol, pch=means.pch, cex=means.cex)
# points(1.5, mean(xst.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]), col=dispcol, pch=means.pch, cex=means.cex)
# 
# text(1, max(xst.disparity.l$disparity[[1]]$elements), "***", cex=means.cex)
# 
# # Third plot
# plot(c(0.25,1.75), plot.ys, type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(plot.ys)[1], 1, range(plot.ys)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=FALSE)
# axis(2)
# 
# points(0.5, mean(as.numeric(xst.Sig2[1, 1:length(hwidx)])), col=ratecol, pch=means.pch, cex=means.cex)
# points(1.5, mean(as.numeric(xst.Sig2[1, 1+length(hwidx):length(slicerange)-1])), col=ratecol, pch=means.pch, cex=means.cex)
# 
# text(1, max(as.numeric(xst.Sig2[1,])), "*", cex=means.cex)

# # Second plot: Disparity means
# plot(c(0.25,1.75), range(xsa.disparity.l$disparity[[1]]$elements), type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(xsa.disparity.l$disparity[[1]]$elements)[1], 1, range(xsa.disparity.l$disparity[[1]]$elements)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=c("HW", "AR"))
# axis(2)
# 
# points(0.5, mean(xsa.disparity.l$disparity[[1]]$elements[1:length(hwidx)]), col=dispcol, pch=means.pch, cex=means.cex)
# points(1.5, mean(xsa.disparity.l$disparity[[1]]$elements[1+length(hwidx):length(slicerange)-1]), col=dispcol, pch=means.pch, cex=means.cex)
# 
# text(1, max(xsa.disparity.l$disparity[[1]]$elements), "**", cex=means.cex)
# 
# # Third plot: Sigma^2 means
# plot(c(0.25,1.75), plot.ys, type="n", axes=FALSE, ann=FALSE)
# 
# segments(1, range(plot.ys)[1], 1, range(plot.ys)[2], lty=2, col=wristcol)
# 
# axis(1, at=c(0.5, 1.5), labels=c("HW", "AR"))
# axis(2)
# 
# points(0.5, mean(as.numeric(xsa.Sig2[1, 1:length(hwidx)])), col=ratecol, pch=means.pch, cex=means.cex)
# points(1.5, mean(as.numeric(xsa.Sig2[1, 1+length(hwidx):length(slicerange)-1])), col=ratecol, pch=means.pch, cex=means.cex)
# 
# text(1, max(as.numeric(xsa.Sig2[1,])), "*", cex=means.cex)
