# Modularity test function - modTest.R

modularity.test<-function(A,partition.gp,iter=999){
  if (length(dim(A))==3){ x<-two.d.array(A)
  p<-dim(A)[1]; k<-dim(A)[2]
  if(length(partition.gp)!=p){stop("Not all landmarks are assigned to a partition.")}
  gps<-as.factor(rep(partition.gp,k,each = k, length=p*k))  }
  if (length(dim(A))==2){ x<-A
  if(length(partition.gp)!=ncol(x)){stop("Not all variables are assigned to a partition.")}
  gps<-as.factor(partition.gp)  }
  ngps<-nlevels(gps)
  CR<-function(x,gps){
    gp.names <- levels(gps)
    g<-factor(as.numeric(gps))
    ngps<-nlevels(g)
    S<-var(x)
    diag(S)<-0
    gps.combo <- combn(ngps, 2)
    CR.gp <- sapply(1:ncol(gps.combo), function(j){ # no loops
      S11<-S[which(g==gps.combo[1,j]),which(g==gps.combo[1,j])]
      S22<-S[which(g==gps.combo[2,j]),which(g==gps.combo[2,j])]
      S12<-S[which(g==gps.combo[1,j]),which(g==gps.combo[2,j])]
      sqrt(sum(colSums(S12^2))/sqrt(sum(S11^2)*sum(S22^2)))
    })
    if(length(CR.gp) > 1) CR.mat <- dist(matrix(0, length(CR.gp),)) else 
      CR.mat = 0
    for(i in 1:length(CR.mat)) CR.mat[[i]] <- CR.gp[i]
    CR.val <- mean(CR.gp) 
    return(CR.val)
  }
  if (length(dim(A))==2){
    CR.obs<-CR(x,gps)
    P.val<-1
    CR.val<-rep(0,iter)
    for(ii in 1:iter){
      partition.gp.r<-sample(partition.gp)
      gps.r<-as.factor(partition.gp.r)
      CR.r<-CR(x,gps.r)
      CR.val[ii]<-CR.r
      P.val<-ifelse(CR.r<=CR.obs, P.val+1,P.val) 
    }
    CR.val[iter+1]=CR.obs
    P.val<-P.val/(iter+1)
    hist(CR.val,30,freq=TRUE,col="gray",xlab="CR Coefficient",xlim=c(min(CR.val),max(CR.val)))
    arrows(CR.obs,50,CR.obs,5,length=0.1,lwd=2)
    return(list(CR=CR.obs,pvalue=P.val,output=CR.val))
  }
  if (length(dim(A))==3){
    CR.vals<-array(NA,dim=90)
    for (i in 0:89){
      rot.mat<-matrix(c(cos(i*pi/180),sin(i*pi/180),0,-sin(i*pi/180),cos(i*pi/180),
                        0,0,0,1),ncol=3)
      A.rot<-array(NA,dim=dim(A))
      for (j in 1:dim(A)[3]){
        A.rot[,,j]<-A[,,j]%*%rot.mat[1:k,1:k]
      }  
      x<-two.d.array(A.rot)
      CR.vals[i+1]<-CR(x,gps)
    } 
    CR.obs<-mean(CR.vals); CR.se<-sd(CR.vals)/90     
    i<-(which.min(abs(CR.vals - CR.obs))-1)  
    rot.mat<-matrix(c(cos(i*pi/180),sin(i*pi/180),0,-sin(i*pi/180),cos(i*pi/180),
                      0,0,0,1),ncol=3)
    A.rot<-array(NA,dim=dim(A))
    for (j in 1:dim(A)[3]){
      A.rot[,,j]<-A[,,j]%*%rot.mat[1:k,1:k]
    }  
    x<-two.d.array(A.rot)
    P.val<-1
    CR.val<-rep(0,iter)
    for(ii in 1:iter){
      partition.gp.r<-sample(partition.gp)
      gps.r<-as.factor(rep(partition.gp.r,k,each = k, length=p*k))
      CR.r<-CR(x,gps.r)
      CR.val[ii]<-CR.r
      P.val<-ifelse(CR.r<=CR.obs, P.val+1,P.val) 
    }
    CR.val[iter+1]=CR.obs
    P.val<-P.val/(iter+1)
    hist(CR.val,30,freq=TRUE,col="gray",xlab="CR Coefficient",xlim=c(0,2))
    arrows(CR.obs,50,CR.obs,5,length=0.1,lwd=2)
    return(list(CR=CR.obs,CInterval=CR.CI<-c(CR.obs-(CR.se*1.96),CR.obs+(CR.se*1.96)),pvalue=P.val))
  }
}