# Write a .pdf file:
pdf(file="wing_profiles_fig.pdf" , width=8, height=8, pointsize=12)

# Calculate the variables for plotting
camber.means <- colMeans(camber.summary)
chord.means <- colMeans(chord.summary.nd)
xsa.means <- colMeans(xsa.summary.nd)
xst.means <- colMeans((xst.summary.nd))

camber.se <- sapply(camber.summary,function(x)sd(x)/sqrt(length(x)))
chord.se <- sapply(chord.summary.nd,function(x)sd(x)/sqrt(length(x)))
xsa.se <- sapply(xsa.summary.nd,function(x)sd(x)/sqrt(length(x)))
xst.se <- sapply(xst.summary.nd,function(x)sd(x)/sqrt(length(x)))

# Some common things for all of the plots
wristdef <- c(24, 26)
axislaboffset <- 0.5
left.axis = -0.5
hwboxcol <- "gray80"
awboxcol <- "gray70"
wristcol <- "gray40"
meancol <- "blue"
mean.lwd <- 2
se.lty <- 2
se.lwd <- 1.5
secol <- "black"

# x <- c(slicerange, rev(slicerange))
# y <- c(clade.means[1,slicecols]+falcons.cl,rev(clade.means[1,slicecols]-falcons.cl))
# polygon(x,y, col=plt.shade[1], border=NA)

# set up pars for a 4 panel plot
par(mfrow=c(4,1),
    mar=c(0,0,0,0),
    oma=c(5,1,0.5,0.5),
    plt=c(0.1, 0.95, 0.1, 0.9))
par(xpd=NA)

# First, camber
yrange <- c(0.05, 0.15)
plot(slicerange, camber.summary[1,], type="n", ylim=yrange, 
     xlim=range(slicerange), axes=FALSE, ann=FALSE)

rect(min(slicerange), yrange[1], wristdef[1], yrange[2], col=hwboxcol, border=NA)
rect(wristdef[2], yrange[1], max(slicerange), yrange[2], col=awboxcol, border=NA)
segments(25, yrange[1], 25, yrange[2], lwd=2, lty=2, col=wristcol)

points(slicerange, camber.means, type="l", lwd=mean.lwd, col=meancol)
points(slicerange, camber.means-camber.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)
points(slicerange, camber.means+camber.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)

axis(1, at = seq(5, 40, by=5), labels = FALSE)
axis(2, at = seq(min(yrange), max(yrange), by=(yrange[2]-yrange[1])/2))

text(left.axis, min(yrange)+((yrange[2]-yrange[1])/2), "Camber", srt=90)

# Second, chord 
yrange <- c(5, 25)
plot(slicerange, chord.summary.nd[1,], type="n", ylim=yrange, 
     xlim=range(slicerange), axes=FALSE, ann=FALSE)

rect(min(slicerange), yrange[1], wristdef[1], yrange[2], col=hwboxcol, border=NA)
rect(wristdef[2], yrange[1], max(slicerange), yrange[2], col=awboxcol, border=NA)
segments(25, yrange[1], 25, yrange[2], lwd=2, lty=2, col=wristcol)

points(slicerange, chord.means, type="l", lwd=mean.lwd, col=meancol)
points(slicerange, chord.means-chord.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)
points(slicerange, chord.means+chord.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)

axis(1, at = seq(5, 40, by=5), labels = FALSE)
axis(2, at = seq(min(yrange), max(yrange), by=(yrange[2]-yrange[1])/2))

text(left.axis, min(yrange)+((yrange[2]-yrange[1])/2), expression("Chord (mm g"^"-1/3"*")"), srt=90)

# Now cross-sectional thickness 
yrange <- c(0, 3)
plot(slicerange, xst.summary.nd[1,], type="n", ylim=yrange, 
     xlim=range(slicerange), axes=FALSE, ann=FALSE)

rect(min(slicerange), yrange[1], wristdef[1], yrange[2], col=hwboxcol, border=NA)
rect(wristdef[2], yrange[1], max(slicerange), yrange[2], col=awboxcol, border=NA)
segments(25, yrange[1], 25, yrange[2], lwd=2, lty=2, col=wristcol)

points(slicerange, xst.means, type="l", lwd=mean.lwd, col=meancol)
points(slicerange, xst.means-xst.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)
points(slicerange, xst.means+xst.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)

axis(1, at = seq(5, 40, by=5), labels = FALSE)
axis(2, at = seq(min(yrange), max(yrange), by=(yrange[2]-yrange[1])/3))

text(left.axis, min(yrange)+((yrange[2]-yrange[1])/3), expression("XS Thickness (mm g"^"-1/3"*")"), srt=90)

# Finally, cross-sectional area 
yrange <- c(0, 20)
plot(slicerange, xsa.summary.nd[1,], type="n", ylim=yrange, 
     xlim=range(slicerange), axes=FALSE, ann=FALSE)

rect(min(slicerange), yrange[1], wristdef[1], yrange[2], col=hwboxcol, border=NA)
rect(wristdef[2], yrange[1], max(slicerange), yrange[2], col=awboxcol, border=NA)
segments(25, yrange[1], 25, yrange[2], lwd=2, lty=2, col=wristcol)

points(slicerange, xsa.means, type="l", lwd=mean.lwd, col=meancol)
points(slicerange, xsa.means-xsa.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)
points(slicerange, xsa.means+xsa.se, type="l", lwd=se.lwd, lty=se.lty, col=secol)

axis(1, at=c(5, 25, 40), labels=c("Tip", "Wrist", "Shoulder"))
axis(2, at = seq(min(yrange), max(yrange), by=(yrange[2]-yrange[1])/2))

text(left.axis, min(yrange)+((yrange[2]-yrange[1])/2), expression("XS Area (mm"^"2"*" g"^"-2/3"*")"), srt=90)
#text(min(slicerange)+(max(slicerange)-min(slicerange))/2, 
#     min(yrange)-((yrange[2]-yrange[1])*axislaboffset), "Position along Wing Span")
#text(min(slicerange),  min(yrange)-((yrange[2]-yrange[1])*axislaboffset), "Distal")
#text(max(slicerange),  min(yrange)-((yrange[2]-yrange[1])*axislaboffset), "Proximal")


# y <- c(clade.means[2,slicecols]+passerines.cl,rev(clade.means[2,slicecols]-passerines.cl))
# polygon(x,y, col=plt.shade[2], border=NA)
# 
# y <- c(clade.means[3,slicecols]+raptors.cl,rev(clade.means[3,slicecols]-raptors.cl))
# polygon(x,y, col=plt.shade[3], border=NA)

dev.off()
